@@ -41,6 +41,10 @@ import upack.write
 __all__ = ('RPMWriter',)
 
 
+def normalize_deps(deps):
+    return ' '.join([d.strip(', ') for d in deps.split(' ') if d.strip(', ')])
+
+
 class RPMWriter(upack.write.Writer):
 
     NAME = 'rpm'
@@ -55,6 +59,8 @@ class RPMWriter(upack.write.Writer):
             epoch_line = 'Epoch:          {epoch}\n'
         else:
             epoch_line = ''
+        ctx.push({'build-requires': normalize_deps(ctx.format('{build-requires}')),
+                  'requires': normalize_deps(ctx.format('{requires}'))})
         pkg = ctx.format(
 '''Name:           {name}
 Version:        {version}
@@ -75,6 +81,7 @@ Conflicts:      {conflicts}
 ''')
         for subpackage in package.subpackages:
             ctx.push(subpackage)
+            ctx.push({'requires': normalize_deps(ctx.format('{requires}'))})
             pkg += ctx.format(
 '''
 %package        -n {name}
@@ -85,6 +92,7 @@ Conflicts:      {conflicts}
 {description}
 ''')
             ctx.pop()
+            ctx.pop()
         pkg += ctx.format(
 '''
 %prep
@@ -146,6 +154,7 @@ make install DESTDIR=$RPM_BUILD_ROOT
 '''))
         ctx.pop()
         ctx.pop()
+        ctx.pop()
 
     def context(self):
         r = upack.context.Raw
